@@ -48,12 +48,14 @@ def clone_tree(args, data, ctx):
                     dst_contents = env.from_string(dst_contents).render(**ctx)
                 with open(dst, mode="w", encoding="UTF-8") as fd:
                     fd.write(str(dst_contents))
+                shutil.copymode(src, dst)
 
             except UnicodeDecodeError:
                 with open(src, mode="rb") as fd:
                     dst_contents = fd.read()
                 with open(dst, mode="wb") as fd:
                     fd.write(dst_contents)
+                shutil.copymode(src, dst)
 
             except jinja2.exceptions.UndefinedError as err:
                 sys.exit(f'error: while rendering "{src}", encountered template error: {err}')
@@ -74,8 +76,9 @@ def clean_tree(args, env, ctx, files):
 
     for file in files:
         path = file["path"]
-        when = file["if"]
+        path = env.from_string(path).render(**ctx)
 
+        when = file["if"]
         when = env.from_string(when).render(**ctx)
         if not when:
             continue
